@@ -404,7 +404,19 @@ att_abort(combat_mode, off, def)
 	setcont(player->cnum, def->own, FOUND_SPY);
 	setcont(def->own, player->cnum, FOUND_SPY);
 #endif /* HIDDEN */
+	if (def->own) {
+		if (def->type == EF_SECTOR &&
+		    !trechk(player->cnum, def->own, LANATT))
+			return abort_attack();
+		else if (def->type == EF_SHIP &&
+			 !trechk(player->cnum, def->own, SEAATT))
+			return abort_attack();
+	}
 #ifdef SLOW_WAR
+	if (combat_mode == A_BOARD)
+		return 0;
+	if (combat_mode == A_ASSAULT && def->own == player->cnum)
+		return 0;
 	natp = getnatp(player->cnum);
 	issneak = getrel(natp, def->own);
 
@@ -417,8 +429,8 @@ att_abort(combat_mode, off, def)
 #ifdef SNEAK_ATTACK
 	getsect(def->x, def->y, &sect);
         if ((issneak != AT_WAR) && (def->own) &&
-		(sect.sct_oldown != player->cnum) && (issneak != SITZKRIEG) &&
-		(issneak != MOBILIZATION)) {
+	    (sect.sct_oldown != player->cnum) && (issneak != SITZKRIEG) &&
+	    (issneak != MOBILIZATION)) {
 		pr("You're not at war with them!\n");
 		if (!confirm("Do you really want to sneak attack (it will cost you $5000) [yn]? ")){
 			pr("Sneak attack cancelled!\n");
@@ -436,14 +448,6 @@ att_abort(combat_mode, off, def)
 		return abort_attack();
 		}	
 #endif /* SLOW_WAR */
-	if (def->own) {
-		if (def->type == EF_SECTOR &&
-		    !trechk(player->cnum, def->own, LANATT))
-			return abort_attack();
-		else if (def->type == EF_SHIP &&
-			 !trechk(player->cnum, def->own, SEAATT))
-			return abort_attack();
-	}
 	return 0;
 }
 
@@ -639,10 +643,10 @@ att_ask_offense(combat_mode, off, def, olist, a_spyp, a_engineerp)
 	int	n;
 	s_char	land_answer[1024];
 	
+	initque(olist);
 	if (att_abort(combat_mode, off, def))
 		return 0;
 	bzero(land_answer, sizeof(land_answer));
-	initque(olist);
 	for (n = 0; n <= off->last; ++n) {
 		off[n].troops = ask_off(combat_mode, off + n, def);
 		if (att_abort(combat_mode, off, def))
@@ -1956,11 +1960,15 @@ do_sneak(def, success)
 	struct	natstr	*natp = getnatp(player->cnum);
 	int	issneak = getrel(natp, def->own);
 
+	if (def->type != EF_SECTOR)
+		return;
+
 	getsect(def->x, def->y, &sect);
 
 	if (issneak == AT_WAR ||
 	    !def->own ||
-	    sect.sct_oldown == player->cnum)
+	    sect.sct_oldown == player->cnum ||
+	    sect.sct_own == player->cnum)
 		return;
 
 	if (success)
